==> numerous-image-tools-1.0.0a22.tar.gz: numerous-image-tools-1.0.0a22/local_packages_to_be_removed/api_client/misc/test/test_read_data/test_read.py <==
from datetime import datetime

from numerous_api_client.client import NumerousClient
import numpy as np

class TestReader():
    def __init__(self):
        pass
        #scenario, components, files = numerous_client.get_scenario()
        #self.input = numerous_client.iter_inputs(scenario, t0=0, dt=60, tag_prefix='', tag_seperator='.',
        #                                 timeout=120, subscribe=False)



    def run(self):
        print('starting')
        #datalist = []
        #for data in self.input:
        #    datalist.append(data["_index"])
        #print(f"total length of data: {len(datalist)}")
        #print(f"unique length of data: {len(np.unique(datalist))}")
        #fa1BRNB5LES1rf5FPna4
        print(numerous_client.get_timeseries_meta_data(project='8ksYmajfoTZqNDfOt4w6', scenario='BePuOF7FqVEYuVcIh6df',
                                         execution=''))

        print(numerous_client.get_timeseries_stats(project='8ksYmajfoTZqNDfOt4w6', scenario='BePuOF7FqVEYuVcIh6df',
                                                       execution=''))

        resp = numerous_client.read_data_as_row(
            project='8ksYmajfoTZqNDfOt4w6', scenario='BePuOF7FqVEYuVcIh6df',
            execution='', tags=['hours'], start=datetime.fromtimestamp(13042800)
        )
        for r in resp:
            #print(r)
            pass
        print('data read')


if __name__ == '__main__':
    numerous_client = NumerousClient()

    t=TestReader()

    t.run()
    numerous_client.close()

==> numerous-image-tools-2.6.0.tar.gz: numerous-image-tools-2.6.0/local_packages_to_be_removed/api_client/misc/test/test_read_data/test_read.py <==
from datetime import datetime

from numerous_api_client.client import NumerousClient
import numpy as np

class TestReader():
    def __init__(self):
        pass
        #scenario, components, files = numerous_client.get_scenario()
        #self.input = numerous_client.iter_inputs(scenario, t0=0, dt=60, tag_prefix='', tag_separator='.',
        #                                 timeout=120, subscribe=False)



    def run(self):
        print('starting')
        #datalist = []
        #for data in self.input:
        #    datalist.append(data["_index"])
        #print(f"total length of data: {len(datalist)}")
        #print(f"unique length of data: {len(np.unique(datalist))}")
        #fa1BRNB5LES1rf5FPna4
        print(numerous_client.get_timeseries_meta_data(project='8ksYmajfoTZqNDfOt4w6', scenario='BePuOF7FqVEYuVcIh6df',
                                         execution=''))

        print(numerous_client.get_timeseries_stats(project='8ksYmajfoTZqNDfOt4w6', scenario='BePuOF7FqVEYuVcIh6df',
                                                       execution=''))

        resp = numerous_client.read_data_as_row(
            project='8ksYmajfoTZqNDfOt4w6', scenario='BePuOF7FqVEYuVcIh6df',
            execution='', tags=['hours'], start=datetime.fromtimestamp(13042800)
        )
        for r in resp:
            #print(r)
            pass
        print('data read')


if __name__ == '__main__':
    numerous_client = NumerousClient()

    t=TestReader()

    t.run()
    numerous_client.close()
